==> dialect-sdk-aliyun-3.1.3.5-sources.jar: cn/herodotus/oss/dialect/aliyun/service/AliyunFileService.java <==
/*
 * Copyright (c) 2020-2030 码匠君<herodotus@aliyun.com>
 *
 * Dante Cloud licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * <http://www.apache.org/licenses/LICENSE-2.0>
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Dante OSS 采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改 Dante Cloud 源码头部的版权声明。
 * 3.请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 <https://gitee.com/herodotus/dante-oss>
 * 5.在修改包名，模块名称，项目代码等时，请注明软件出处 <https://gitee.com/herodotus/dante-oss>
 * 6.若您的项目无法满足以上几点，可申请商业授权
 */

package cn.herodotus.oss.dialect.aliyun.service;

import cn.herodotus.oss.dialect.aliyun.definition.service.BaseAliyunService;
import cn.herodotus.oss.dialect.core.client.AbstractOssClientObjectPool;
import cn.herodotus.oss.dialect.core.exception.OssIOException;
import com.aliyun.oss.OSS;
import com.aliyun.oss.model.DownloadFileRequest;
import com.aliyun.oss.model.DownloadFileResult;
import com.aliyun.oss.model.UploadFileRequest;
import com.aliyun.oss.model.UploadFileResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;

/**
 * <p>Description: Aliyun OSS 文件操作 Service </p>
 *
 * @author : gengwei.zheng
 * @date : 2023/7/23 18:42
 */
@Service
public class AliyunFileService extends BaseAliyunService {

    private static final Logger log = LoggerFactory.getLogger(AliyunFileService.class);

    public AliyunFileService(AbstractOssClientObjectPool<OSS> ossClientObjectPool) {
        super(ossClientObjectPool);
    }

    public UploadFileResult uploadFile(UploadFileRequest request) {
        String function = "uploadFile";

        OSS client = getClient();

        try {
            return client.uploadFile(request);
        } catch (Throwable e) {
            log.error("[Herodotus] |- Aliyun OSS catch Throwable in [{}].", function, e);
            throw new OssIOException(e.getMessage());
        } finally {
            close(client);
        }
    }

    public DownloadFileResult downloadFile(DownloadFileRequest request) {
        String function = "downloadFile";

        OSS client = getClient();

        try {
            return client.downloadFile(request);
        } catch (Throwable e) {
            log.error("[Herodotus] |- Aliyun OSS catch Throwable in [{}].", function, e);
            throw new OssIOException(e.getMessage());
        } finally {
            close(client);
        }
    }
}

==> dialect-sdk-aliyun-3.1.6.0-sources.jar: cn/herodotus/oss/dialect/aliyun/service/AliyunFileService.java <==
/*
 * Copyright (c) 2020-2030 码匠君<herodotus@aliyun.com>
 *
 * Dante Cloud licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * <http://www.apache.org/licenses/LICENSE-2.0>
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Dante OSS 采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改 Dante Cloud 源码头部的版权声明。
 * 3.请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 <https://gitee.com/herodotus/dante-oss>
 * 5.在修改包名，模块名称，项目代码等时，请注明软件出处 <https://gitee.com/herodotus/dante-oss>
 * 6.若您的项目无法满足以上几点，可申请商业授权
 */

package cn.herodotus.oss.dialect.aliyun.service;

import cn.herodotus.engine.assistant.core.definition.AbstractObjectPool;
import cn.herodotus.oss.dialect.aliyun.definition.service.BaseAliyunService;
import cn.herodotus.oss.dialect.core.exception.OssIOException;
import com.aliyun.oss.OSS;
import com.aliyun.oss.model.DownloadFileRequest;
import com.aliyun.oss.model.DownloadFileResult;
import com.aliyun.oss.model.UploadFileRequest;
import com.aliyun.oss.model.UploadFileResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;

/**
 * <p>Description: Aliyun OSS 文件操作 Service </p>
 *
 * @author : gengwei.zheng
 * @date : 2023/7/23 18:42
 */
@Service
public class AliyunFileService extends BaseAliyunService {

    private static final Logger log = LoggerFactory.getLogger(AliyunFileService.class);

    public AliyunFileService(AbstractObjectPool<OSS> ossClientObjectPool) {
        super(ossClientObjectPool);
    }

    public UploadFileResult uploadFile(UploadFileRequest request) {
        String function = "uploadFile";

        OSS client = getClient();

        try {
            return client.uploadFile(request);
        } catch (Throwable e) {
            log.error("[Herodotus] |- Aliyun OSS catch Throwable in [{}].", function, e);
            throw new OssIOException(e.getMessage());
        } finally {
            close(client);
        }
    }

    public DownloadFileResult downloadFile(DownloadFileRequest request) {
        String function = "downloadFile";

        OSS client = getClient();

        try {
            return client.downloadFile(request);
        } catch (Throwable e) {
            log.error("[Herodotus] |- Aliyun OSS catch Throwable in [{}].", function, e);
            throw new OssIOException(e.getMessage());
        } finally {
            close(client);
        }
    }
}
